@@ -1,4 +1,4 @@
-from typing import List, Union
+from typing import Callable, Dict, List, Union
 
 from mlc.datasets.dataset import Dataset
 from mlc.datasets.samples.airlines import datasets as airlines_datasets
@@ -7,7 +7,7 @@ from mlc.datasets.samples.electricity import datasets as electricity_datasets
 from mlc.datasets.samples.lcld import datasets as lcld_datasets
 from mlc.datasets.samples.url import datasets as url_datasets
 
-datasets: List[Dataset] = (
+datasets: List[Dict[str, Union[str, Callable[[], Dataset]]]] = (
     lcld_datasets
     + ctu_13_neris_datasets
     + electricity_datasets
@@ -24,8 +24,9 @@ def load_datasets(dataset_names: Union[str, List[str]]) -> List[Dataset]:
 
     if isinstance(dataset_names, str):
         dataset_names = [dataset_names]
-    datasets_out = list(filter(lambda e: e.name in dataset_names, datasets))
 
+    datasets_out = list(filter(lambda e: e["name"] in dataset_names, datasets))
+    datasets_out = [e["fun_create"]() for e in datasets_out]
     if len(datasets_out) != len(dataset_names):
         raise NotImplementedError("At least one dataset is not available.")
 
