@@ -1,18 +1,19 @@
 import importlib
-from typing import Union
+from typing import Any, Dict, Type, Union
 
-from mlc.datasets.samples import load_dataset
+from mlc.models.model import Model
+from mlc.models.samples import load_model
 
 
-def get_dataset_from_config(config: dict):
-    name = config.get("name")
+def get_model_from_config(config: Dict[str, Any]) -> Type[Model]:
+    name = config["name"]
 
     # If it is a known dataset
     if len(config.keys()) == 1:
-        return load_dataset(name)
+        return load_model(name)
 
     # Else load and do
-    models = importlib.import_module(config.get("source")).models
+    models = importlib.import_module(config["source"]).models
     models_out = list(filter(lambda e: e[0] in [name], models))
     models_out = [e[1] for e in models_out]
 
@@ -21,7 +22,7 @@ def get_dataset_from_config(config: dict):
     return models_out[0]
 
 
-def get_dataset(config: Union[dict, str]):
+def get_model(config: Union[Dict[str, Any], str]) -> Type[Model]:
     if isinstance(config, str):
         config = {"name": config}
-    return get_dataset_from_config(config)
+    return get_model_from_config(config)
