@@ -1,7 +1,14 @@
+from typing import Any, Optional
+
 import numpy as np
+import numpy.typing as npt
 
 
-def cut_in_batch(arr, n_desired_batch=1, batch_size=None):
+def cut_in_batch(
+    arr: npt.NDArray[Any],
+    n_desired_batch: int = 1,
+    batch_size: Optional[int] = None,
+):
 
     if batch_size is None:
         n_batch = min(n_desired_batch, len(arr))
